@@ -2,20 +2,22 @@ from typing import (Sequence,
                     Tuple,
                     Type)
 
-from ground.core.hints import (Coordinate,
-                               Point)
+from ground.core.hints import (Contour,
+                               Point,
+                               Scalar)
 from ground.core.primitive import rationalize
 
 
-def centroid(vertices: Sequence[Point], point_cls: Type[Point]) -> Point:
-    x_numerator, y_numerator, double_area = centroid_components(vertices)
+def centroid(contour: Contour, point_cls: Type[Point]) -> Point:
+    x_numerator, y_numerator, double_area = centroid_components(
+            contour.vertices)
     inverted_divisor = 1 / (3 * double_area)
     return point_cls(x_numerator * inverted_divisor,
                      y_numerator * inverted_divisor)
 
 
 def centroid_components(vertices: Sequence[Point]
-                        ) -> Tuple[Coordinate, Coordinate, Coordinate]:
+                        ) -> Tuple[Scalar, Scalar, Scalar]:
     double_area = x_numerator = y_numerator = 0
     prev_vertex = vertices[-1]
     prev_x, prev_y = rationalize(prev_vertex.x), rationalize(prev_vertex.y)
