@@ -9,11 +9,12 @@ from .hints import (Point,
                     TernaryPointFunction)
 
 
-def to_convex_hull(orientation: TernaryPointFunction[Orientation],
-                   points: Sequence[Point]) -> List[Point]:
+def to_convex_hull(points: Sequence[Point],
+                   orienteer: TernaryPointFunction[Orientation]
+                   ) -> List[Point]:
     points = _to_unique_just_seen(sorted(points))
-    lower, upper = (_to_sub_hull(orientation, points),
-                    _to_sub_hull(orientation, reversed(points)))
+    lower, upper = (_to_sub_hull(points, orienteer),
+                    _to_sub_hull(reversed(points), orienteer))
     return lower[:-1] + upper[:-1] or points
 
 
@@ -24,8 +25,8 @@ def _to_unique_just_seen(iterable: Iterable[_T]) -> Sequence[_T]:
     return [key for key, _ in groupby(iterable)]
 
 
-def _to_sub_hull(orienteer: TernaryPointFunction[Orientation],
-                 points: Iterable[Point]) -> List[Point]:
+def _to_sub_hull(points: Iterable[Point],
+                 orienteer: TernaryPointFunction[Orientation]) -> List[Point]:
     result = []
     for point in points:
         while len(result) >= 2:
